# PhysicalRiskMetadataIndicatorResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**hazard** | **str** | Climate hazard | 
**indicator** | **str** | Risk indicator | 
**unit** | **str** | Value unit (e.g. millimeter, day, degree_celsius, etc) | 
**value_min** | **float** | Minimum possible value | 
**value_max** | **float** | Maximum possible value | 
**value_norm** | **float** | Maximum value expected when value is normalized | 
**spatial_resolution** | **float** | Spatial resolution of datapoint in meters | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


